@@ -15,12 +15,14 @@ from xj_user.utils.custom_response import util_response
 class WechetLogin(APIView):
     # 微信手机号码登录
     def post(self, request):
-        phone_code = self.request.data.get('phone_code', None)
-        login_code = self.request.data.get('login_code', None)
+        phone_code = request.data.get('phone_code', None)
+        login_code = request.data.get('login_code', None)
+        sso_serve_id = request.data.get('sso_serve_id', None)
+
         if not phone_code:
             return util_response(err=6558, msg='参数错误')
         app = WechatService()
-        err, data = app.wechat_login(phone_code=phone_code,login_code=login_code)
+        err, data = app.wechat_login(phone_code=phone_code, login_code=login_code, sso_serve_id=sso_serve_id)
         if err == 0:
             return util_response(data=data)
         else:
