@@ -26,14 +26,18 @@ class PermissionValue(models.Model):
     """
     permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, help_text='')
     module = models.CharField(verbose_name='模型名称', max_length=255, blank=True, null=True, help_text='')
-    feature = models.CharField(verbose_name='功能专注点', max_length=255, blank=True, null=True, help_text='group: 按用户组给权限, route: 按路由给权限, point: 按交互点给权限, ..., category: 类别权限')
-    permission_value = models.CharField(verbose_name='权限标识值', max_length=255, blank=True, null=True, help_text='权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译')
+    feature = models.CharField(verbose_name='功能专注点', max_length=255, blank=True, null=True,
+                               help_text='group: 按用户组给权限, route: 按路由给权限, point: 按交互点给权限, ..., category: 类别权限')
+    permission_value = models.CharField(verbose_name='权限标识值', max_length=255, blank=True, null=True,
+                                        help_text='权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译')
     type = models.CharField(verbose_name='类型', max_length=255, blank=True, null=True, help_text='暂不使用')
     relate_value = models.CharField(verbose_name='权限内容关联值', max_length=255, blank=True, null=True, help_text='')
     config = models.JSONField(verbose_name='权限更多配置', max_length=255, blank=True, null=True, help_text='权限更多配置，常用于前端路由')
     is_enable = models.CharField(verbose_name='是否启用权限', max_length=1, blank=True, null=True, help_text='')
-    is_system = models.CharField(verbose_name='是否系统权限', max_length=1, blank=True, null=True, help_text='是否系统权限，系统权限不可以删除，默认SUPER_ADMINISTRATOR的所有value都是系统权限。')
-    is_ban = models.CharField(verbose_name='是否禁用', max_length=1, blank=True, null=True, help_text='是否全部禁用该权限，Y禁用，N允许，默认N。使用减法原则，约定无权限值则视为允许。')
+    is_system = models.CharField(verbose_name='是否系统权限', max_length=1, blank=True, null=True,
+                                 help_text='是否系统权限，系统权限不可以删除，默认SUPER_ADMINISTRATOR的所有value都是系统权限。')
+    is_ban = models.CharField(verbose_name='是否禁用', max_length=1, blank=True, null=True,
+                              help_text='是否全部禁用该权限，Y禁用，N允许，默认N。使用减法原则，约定无权限值则视为允许。')
     ban_view = models.CharField(verbose_name='是否可看', max_length=1, blank=True, null=True, help_text='')
     ban_edit = models.CharField(verbose_name='是否编辑', max_length=1, blank=True, null=True, help_text='')
     ban_add = models.CharField(verbose_name='是否插入', max_length=1, blank=True, null=True, help_text='')
@@ -55,7 +59,8 @@ class Group(models.Model):
     id = models.AutoField(verbose_name='ID', primary_key=True)
     group = models.CharField(verbose_name='用户组', max_length=32, blank=True, null=True, help_text='')
     parent_group = models.CharField(verbose_name='父组', max_length=32, blank=True, null=True, help_text='')
-    permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, blank=True, null=True, help_text='')
+    permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, blank=True, null=True,
+                                   help_text='')
     description = models.CharField(verbose_name='描述', max_length=32, blank=True, null=True, help_text='')
 
     class Meta:
@@ -70,15 +75,21 @@ class BaseInfo(models.Model):
     """ 1、User_Base_Info 基础信息表 [NF1] """
     # platform_uid = models.BigIntegerField(verbose_name='平台用户ID', db_index=True)
     # platform = models.ForeignKey(Platform, on_delete=models.DO_NOTHING, verbose_name='平台ID',)
-    user_name = models.CharField(verbose_name='用户名', max_length=128, unique=True, blank=True, null=True, db_index=True, help_text='登录的用户名')
-    full_name = models.CharField(verbose_name='姓名', max_length=128, blank=True, null=True, db_index=True, help_text='用户的真实姓名（未实名验证）')
+    user_name = models.CharField(verbose_name='用户名', max_length=128, unique=True, blank=True, null=True, db_index=True,
+                                 help_text='登录的用户名')
+    full_name = models.CharField(verbose_name='姓名', max_length=128, blank=True, null=True, db_index=True,
+                                 help_text='用户的真实姓名（未实名验证）')
     nickname = models.CharField(verbose_name='昵称', max_length=128, blank=True, null=True, help_text='')
-    phone = models.CharField(verbose_name='手机', max_length=128, unique=True, blank=True, null=True, db_index=True, help_text='登录用的手机号')
+    phone = models.CharField(verbose_name='手机', max_length=128, unique=True, blank=True, null=True, db_index=True,
+                             help_text='登录用的手机号')
     email = models.EmailField(verbose_name='邮箱', unique=True, blank=True, null=True, db_index=True, help_text='登录用的邮箱')
-    wechat_openid = models.CharField(verbose_name='微信开放号', max_length=128, unique=True, blank=True, null=True, db_index=True, help_text='微信用户开放ID，注意openid是微信的专用名词')
+    wechat_openid = models.CharField(verbose_name='微信开放号', max_length=128, unique=True, blank=True, null=True,
+                                     db_index=True, help_text='微信用户开放ID，注意openid是微信的专用名词')
     user_info = models.JSONField(verbose_name='用户信息', blank=True, null=True, help_text='用户扩展信息')
-    user_group = models.ForeignKey(Group, verbose_name='用户分组', blank=True, null=True, on_delete=models.DO_NOTHING, help_text='')
-    permission = models.ForeignKey(Permission, verbose_name='用户权限', blank=True, null=True, on_delete=models.DO_NOTHING, help_text='')
+    user_group = models.ForeignKey(Group, verbose_name='用户分组', blank=True, null=True, on_delete=models.DO_NOTHING,
+                                   help_text='')
+    permission = models.ForeignKey(Permission, verbose_name='用户权限', blank=True, null=True, on_delete=models.DO_NOTHING,
+                                   help_text='')
     register_time = models.DateTimeField(verbose_name='注册时间', default=timezone.now, help_text='')
 
     class Meta:
@@ -103,7 +114,8 @@ class Auth(models.Model):
     password = models.CharField(verbose_name='密码', max_length=255, blank=True, null=True, help_text='登录的密码')
     plaintext = models.CharField(verbose_name='PT', max_length=255, blank=True, null=True, help_text='')
     salt = models.CharField(verbose_name='盐', max_length=32, blank=True, null=True, help_text='加密盐由六位数字和字母组成，区分大小写')
-    algorithm = models.CharField(verbose_name='加密算法', max_length=255, blank=True, null=True, help_text='系统同时支持多种加密算法，旧版为MD5，新版为SHA1')
+    algorithm = models.CharField(verbose_name='加密算法', max_length=255, blank=True, null=True,
+                                 help_text='系统同时支持多种加密算法，旧版为MD5，新版为SHA1')
     token = models.CharField(verbose_name='临时令牌', max_length=255, blank=True, null=True, help_text='用户令牌，用于验证用户有效期')
     ticket = models.CharField(verbose_name='临时票据', max_length=255, blank=True, null=True, help_text='用户提供第三方单点登录的票据')
     create_time = models.DateTimeField(verbose_name='创建时间', auto_now_add=True, help_text='')
@@ -121,8 +133,10 @@ class Auth(models.Model):
 
 class DetailInfo(models.Model):
     """ 3、User_Detail_Info 详细信息表 [1-1] """
-    user = models.OneToOneField(BaseInfo, verbose_name='用户', unique=True, on_delete=models.DO_NOTHING, help_text='登录用的用户名')
-    real_name = models.CharField(verbose_name='真实姓名', max_length=255, blank=True, null=True, db_index=True, help_text='实名认证后的真名')
+    user = models.OneToOneField(BaseInfo, verbose_name='用户', unique=True, on_delete=models.DO_NOTHING,
+                                help_text='登录用的用户名')
+    real_name = models.CharField(verbose_name='真实姓名', max_length=255, blank=True, null=True, db_index=True,
+                                 help_text='实名认证后的真名')
     sex = models.CharField(verbose_name='性别', max_length=1, blank=True, null=True, help_text='0未知 1男 2女')
     birth = models.DateField(verbose_name='生日', blank=True, null=True, help_text='')
     tags = models.CharField(verbose_name='个人标签', max_length=255, blank=True, null=True, help_text='多个标签以英文;号为分隔符')
@@ -131,7 +145,8 @@ class DetailInfo(models.Model):
     cover = models.CharField(verbose_name='个人封面', max_length=255, blank=True, null=True, help_text='')
     language = models.CharField(verbose_name='语言', max_length=32, blank=True, null=True, help_text='')
     region_code = models.BigIntegerField(verbose_name='行政区划编码', blank=True, null=True, db_index=True, help_text='')
-    more = models.JSONField(verbose_name='更多信息', max_length=255, blank=True, null=True, help_text='更多信息用来存放用户可能填写的扩展内容，由于很多信息不是必填或必须存在的，因此不单独建字段。')
+    more = models.JSONField(verbose_name='更多信息', max_length=255, blank=True, null=True,
+                            help_text='更多信息用来存放用户可能填写的扩展内容，由于很多信息不是必填或必须存在的，因此不单独建字段。')
     field_1 = models.CharField(verbose_name='字段1', max_length=255, blank=True, null=True, help_text='')
     field_2 = models.CharField(verbose_name='字段2', max_length=255, blank=True, null=True, help_text='')
     field_3 = models.CharField(verbose_name='字段3', max_length=255, blank=True, null=True, help_text='')
@@ -159,8 +174,10 @@ class DetailInfo(models.Model):
 
 class ExtendField(models.Model):
     """ 3、User_Extend_Field 扩展字段表 [1-1] """
-    field = models.CharField(verbose_name='自定义字段', max_length=255, unique=True, blank=True, null=True, db_index=True, help_text='当已有字段不能满足的时候的扩展字段')
-    field_index = models.CharField(verbose_name='映射索引名', max_length=255, unique=True, blank=True, null=True, help_text='映射到扩展数据表的字段名，如：field_x')
+    field = models.CharField(verbose_name='自定义字段', max_length=255, unique=True, blank=True, null=True, db_index=True,
+                             help_text='当已有字段不能满足的时候的扩展字段')
+    field_index = models.CharField(verbose_name='映射索引名', max_length=255, unique=True, blank=True, null=True,
+                                   help_text='映射到扩展数据表的字段名，如：field_x')
     description = models.CharField(verbose_name='字段描述', max_length=255, blank=True, null=True, help_text='')
 
     class Meta:
@@ -208,7 +225,8 @@ class History(models.Model):
 class RestrictRegion(models.Model):
     """6、*User_Restrict_Region 限制范围表"""
     user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, help_text='用户ID')
-    region_code = models.BigIntegerField(verbose_name='允许的行政区划编码', blank=True, null=True, db_index=True, help_text='在国内参考 GB/T2260-2002中国行政区划代码，有6位数 9位数 12位数，非中国地区以9开头')
+    region_code = models.BigIntegerField(verbose_name='允许的行政区划编码', blank=True, null=True, db_index=True,
+                                         help_text='在国内参考 GB/T2260-2002中国行政区划代码，有6位数 9位数 12位数，非中国地区以9开头')
 
     class Meta:
         db_table = 'user_restrict_region'
@@ -238,7 +256,8 @@ class Platform(models.Model):
 
 class PlatformsToUsers(models.Model):
     """ 8、*User_Platforms_To_Users - 多对多平台记录表 [N-N] """
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id', help_text='')
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id',
+                             help_text='')
     platform = models.ForeignKey(Platform, verbose_name='平台', on_delete=models.DO_NOTHING, help_text='')
     platform_user_id = models.BigIntegerField(verbose_name='平台用户ID', blank=True, null=True, db_index=True, help_text='')
 
@@ -254,9 +273,11 @@ class PlatformsToUsers(models.Model):
 
 class ContactBook(models.Model):
     """ 12、*user_contact_book - 一对多联系簿表 [1-N] """
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', related_name="user_set", on_delete=models.DO_NOTHING, help_text='')
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', related_name="user_set", on_delete=models.DO_NOTHING,
+                             help_text='')
     # user_id = models.IntegerField(verbose_name='用户', help_text='')
-    friend = models.ForeignKey(BaseInfo, verbose_name='朋友', related_name="friend_set", on_delete=models.DO_NOTHING, help_text='待删')
+    friend = models.ForeignKey(BaseInfo, verbose_name='朋友', related_name="friend_set", on_delete=models.DO_NOTHING,
+                               help_text='待删')
     phone = models.JSONField(verbose_name='手机号', blank=True, null=True, help_text='')
     phones = models.JSONField(verbose_name='多个手机号', blank=True, null=True, help_text='')
     telephone = models.JSONField(verbose_name='电话号码', blank=True, null=True, help_text='')
@@ -267,7 +288,6 @@ class ContactBook(models.Model):
     more = models.JSONField(verbose_name='更多', blank=True, null=True, help_text='')
     remarks = models.CharField(verbose_name='标记', max_length=255, blank=True, null=True, help_text='')
 
-
     class Meta:
         db_table = 'user_contact_book'
         verbose_name_plural = "09. 用户 - 联系簿"
@@ -275,3 +295,35 @@ class ContactBook(models.Model):
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
         return f"{self.user_name}"
+
+
+class UserSsoServe(models.Model):
+    sso_code = models.CharField(verbose_name='单点登录代码', max_length=255, blank=True, null=True, help_text='')
+    sso_name = models.CharField(verbose_name='单点登录名', max_length=255, blank=True, null=True, help_text='')
+    sso_url = models.CharField(verbose_name='单点登录地址', max_length=255, blank=True, null=True, help_text='')
+    description = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
+
+    class Meta:
+        db_table = 'user_sso_serve'
+        verbose_name_plural = "单点登录服务表"
+
+    def __str__(self):
+        # return f"{self.user_name}({self.full_name})"
+        return f"{self.sso_code}"
+
+
+class UserSsoToUser(models.Model):
+    sso_serve = models.ForeignKey(UserSsoServe, verbose_name='单点登录服务ID', on_delete=models.DO_NOTHING,
+                                  help_text='')
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, help_text='')
+    sso_unicode = models.CharField(verbose_name='单点登录地址', max_length=255, blank=True, null=True, help_text='')
+    sso_ticket = models.CharField(verbose_name='描述', max_length=255, blank=True, null=True, help_text='')
+    app_id = models.CharField(verbose_name='服务授权app', max_length=255, blank=True, null=True, help_text='')
+
+    class Meta:
+        db_table = 'user_sso_to_user'
+        verbose_name_plural = "单点登录用户映射表"
+
+    def __str__(self):
+        # return f"{self.user_name}({self.full_name})"
+        return f"{self.sso_unicode}"
