@@ -9,7 +9,8 @@
 
 from django.db.models import F
 
-from ..models import ExtendFiled, DetailInfo, BaseInfo
+from xj_role.models import UserToGroup, UserToRole
+from ..models import ExtendField, DetailInfo, BaseInfo
 from ..utils.model_handle import *
 
 
@@ -19,14 +20,14 @@ class DetailInfoService:
         if not request_dict:
             return {}
         # 冗余字段 请求参数转换
-        filed_map = ExtendFiled.objects.values()
+        filed_map = ExtendField.objects.values()
         filed_map = {item['field']: item['field_index'] for item in filed_map}
         return {filed_map.get(k, k): v for k, v in request_dict.items()}
 
     @staticmethod
     def transform_result(result):
         # 冗余字段 结果集转换
-        filed_map = list(ExtendFiled.objects.all().values("field", 'field_index'))
+        filed_map = list(ExtendField.objects.all().values("field", 'field_index'))
         filed_map = {item['field_index']: item['field'] for item in filed_map}
         transformed_list = []
         if type(result) is dict:
@@ -46,8 +47,17 @@ class DetailInfoService:
 
     @staticmethod
     def get_list_detail(params, user_id_list=None):
-        if user_id_list:
-            return DetailInfo.objects.filter(user_id__in=user_id_list).annotate(full_name=F("user__full_name")).values("user_id", "full_name", "avatar")
+        if not user_id_list is None:
+            res_obj = DetailInfo.objects.filter(user_id__in=user_id_list) \
+                .annotate(full_name=F("user__full_name")) \
+                .annotate(user_name=F("user__user_name")) \
+                .annotate(nickname=F("user__nickname"))
+
+            res_data = []
+            if res_obj:
+                res_data = res_obj.values("user_id", "user_name", "nickname", "full_name", "avatar")
+            return res_data
+
         # 查询用户详细信息列表
         transformed_dict = DetailInfoService.transform_params(params)
         page = transformed_dict.pop('page', 1)
@@ -73,10 +83,13 @@ class DetailInfoService:
         user_detail = DetailInfo.objects.filter(user_id=user_id) \
             .annotate(user_name=F("user_id__user_name")) \
             .annotate(nickname=F("user_id__nickname")) \
+            .annotate(phone=F("user__phone")) \
+            .annotate(email=F("user__email")) \
+            .annotate(register_time=F("user__register_time")) \
             .values().first()
         if not user_detail:
-            return None, "该用户没用填写详细信息"
-        field_set = ExtendFiled.objects.all().values("field", 'field_index')
+            return [], None
+        field_set = ExtendField.objects.all().values("field", 'field_index')
         field_dict = {item['field_index']: item['field'] for item in field_set}
         # 字段映射转换
         user_detail_extended = {
