@@ -6,6 +6,9 @@ import re
 
 from django.contrib.auth.hashers import make_password
 from pathlib import Path
+
+from django.forms import model_to_dict
+
 from main.settings import BASE_DIR
 from django.contrib.auth.hashers import check_password
 from django.core.paginator import Paginator
@@ -16,7 +19,7 @@ import jwt
 from rest_framework import serializers
 
 from config.config import Config
-from ..models import Auth
+from ..models import Auth, DetailInfo
 from ..models import BaseInfo
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
@@ -111,12 +114,13 @@ class UserService:
             'user_id',
             'user_name',
             'full_name',
+            'nickname',
             'phone',
             'email',
             'wechat_openid',
             'user_info',
-            'user_group_id',
-            'user_group_value',
+            # 'user_group_id',
+            # 'user_group_value',
             'permission_id',
             'permission_value'
         )
@@ -343,11 +347,11 @@ class UserService:
             if not account:
                 return None, "account必填"
 
-            if not password:
-                return None, "密码必填"
+            # if not password:
+            #     return None, "密码必填"
 
-            if not full_name:
-                return None, "full_name"
+            # if not full_name:
+            #     return None, "full_name"
 
             # 账号类型判断
             if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
@@ -412,19 +416,28 @@ class UserService:
 
     @staticmethod
     def user_basic_message(user_id):
-        user_basic_message = BaseInfo.objects.filter(id=user_id)
-
+        # user_basic_message = BaseInfo.objects.filter(id=user_id).first()
+        res_data = {}
+        user_basic_message = BaseInfo.objects.filter(id=user_id).annotate(user_id=F("id")).first()
         if not user_id:
             return None, "user_id不能为空"
         if user_basic_message:
-            res_data = user_basic_message.values("id", "user_name", "nickname", "full_name", "phone", "email",
-                                                 "register_time")
+            res_data = model_to_dict(user_basic_message)
+            detailinfo = DetailInfo.objects.filter(user_id=user_id).first()
+            avatar = None
+            if detailinfo:
+                detail_info = model_to_dict(detailinfo)
+                avatar = detail_info['avatar']
+            res_data['avatar'] = avatar
+            res_data['user_id'] = user_id
+            # res_data = user_basic_message.values("id", "user_name", "nickname", "full_name", "phone", "email",
+            #                                      "register_time")
 
-        return list(res_data), None
+        return res_data, None
 
     @staticmethod
     def user_edit(params):
-        # 添加逻辑
+        # 修改逻辑
         try:
             account = str(params.get('account', ''))
             password = str(params.get('password', ''))
@@ -440,8 +453,8 @@ class UserService:
             # if not password:
             #     return None, "密码必填"
 
-            if not full_name:
-                return None, "full_name"
+            # if not full_name:
+            #     return None, "full_name"
             if not user_id:
                 return None, " 用户id不能为空"
             # 账号类型判断
@@ -494,6 +507,66 @@ class UserService:
         except:
             return None, "未知错误"
 
+    @staticmethod
+    def user_role_edit(params):
+        # 修改逻辑
+        try:
+            account = str(params.get('account', ''))
+            phone = str(params.get('phone', ''))
+            full_name = str(params.get('full_name', ''))
+            nickname = str(params.get('nickname', ''))
+            user_id = params.get('user_id', '')
+            base_info = {}
+            if not user_id:
+                return None, " 用户id不能为空"
+            # 边界检查
+            if account:
+                # 账号类型判断
+                if re.match(r'(^1[356789]\d{9}$)|(^\+?[78]\d{10}$)', account):
+                    account_type = 'phone'
+                elif re.match(r'^\w+[\w\.\-\_]*@\w+[\.\w]*\.\w{2,}$', account):
+                    account_type = 'email'
+                elif re.match(r'^[A-z\u4E00-\u9FA5]+\w*$', account):
+                    account_type = 'username'
+                else:
+                    return None, "账号必须是用户名、手机或者邮箱，用户名不能是数字开头"
+                # 检查账号是否存在
+                user_list = None
+                if account_type == 'phone':
+                    user_list = BaseInfo.objects.filter(Q(phone=account), ~Q(id=user_id))
+                elif account_type == 'email':
+                    user_list = BaseInfo.objects.filter(Q(email=account), ~Q(id=user_id))
+                elif account_type == 'username':
+                    user_list = BaseInfo.objects.filter(Q(user_name=account), ~Q(id=user_id))
+                if user_list.count() and account_type == 'phone':
+                    return None, "手机已被注册: " + account
+                elif user_list.count() and account_type == 'email':
+                    return None, "邮箱已被注册: " + account
+                elif user_list.count() and account_type == 'username':
+                    return None, "用户名已被注册: " + account
+
+                base_info['user_name'] = account if account_type == 'username' else ''
+                base_info['phone'] = account if account_type == 'phone' else phone
+                base_info['email'] = account if account_type == 'email' else ''
+
+            if full_name:
+                base_info['full_name'] = full_name
+
+            if nickname:
+                base_info['nickname'] = nickname
+
+            BaseInfo.objects.filter(id=user_id).update(**base_info)
+
+            return {"user_id": user_id}, None
+        except SyntaxError:
+            return None, "语法错误"
+        except LookupError:
+            return None, "无效数据查询"
+        except Exception as valueError:
+            return None, valueError.msg if hasattr(valueError, 'msg') else valueError.args
+        except:
+            return None, "未知错误"
+
     @staticmethod
     def user_delete(id):
         if not id:
