@@ -20,6 +20,8 @@ from .apis import user_password
 from .apis import user_permission
 from .apis import user_platform
 from .apis import user_register
+from .apis import user_sso_serve
+
 # from .apis import user_short_message
 
 # 应用名称
@@ -53,8 +55,11 @@ urlpatterns = [
     re_path(r'^group_list/?$', user_group.GroupAPIView.list, ),
 
     # re_path(r'^send_message/?$', user_short_message.UserShortMessage.as_view(), ),
-    re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.as_view(), ),
+    # re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.as_view(), ),
+    re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.sms_login),
 
-    re_path(r'^permission/?$', user_permission.UserPermissions.as_view(), ),
+    re_path(r'^login/?$', user_login.UserLogin.as_view(), ),
+
+    re_path(r'^sso_serve/?$', user_sso_serve.UserSsoServe.as_view(), ),
 
 ]
